#!/bin/sh
##------------------------------------------------------------------------------
## local: opt\files\srv\www\admin\macfilter.cgi
## fli4l: srv/www/admin/macfilter.cgi
## DE: OPT_HTTPD Webadmin Webseite fr MACFilter
## EN: OPT_HTTPD webadmin page for MACFilter
##------------------------------------------------------------------------------
##
## Creation:       01.11.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Last modified:  01.11.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Version:        0.1.0-0.1.3
##
##------------------------------------------------------------------------------
## Files:    /var/run/macfilter.conf
##------------------------------------------------------------------------------
. /srv/www/include/cgi-helper
. /var/run/macfilter.conf

# DE: Rechte kontollieren
# EN: check rights
: ${FORM_action:=view}
check_rights "macfilter" "$FORM_action"

show_html_header "MACFilter"

#-------------------------------------------------------------------------------
# DE: Aktion durchfhren
# EN: perform action
#-------------------------------------------------------------------------------
case $FORM_action in
    #----------------------------------------
    # DE: Mac hinzufgen
    # EN: add mac
    #----------------------------------------
    add)
        /usr/local/bin/macfilter.sh "add" $FORM_mac
        show_info "$_header_add_mac" "$_text_add_mac<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Mac entfernen
    # EN:remove mac
    #----------------------------------------
    remove)
        /usr/local/bin/macfilter.sh "remove" $FORM_mac
        show_info "$_header_remove_mac" "$_text_remove_mac<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Macfilter starten
    # EN: start macfilter
    #----------------------------------------
    startfilter)
        if [ `iptables -nvL macfilter | grep "Chain" | cut -dr -f2 | cut -b3-4` = "0" ]
        then
            /usr/local/bin/macfilter.sh "startfilter"
            show_info "$_header_starting" "$_text_starting<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
            echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
        else
            show_error "$_header_error" "$_text_already_running<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
            echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
        fi
    ;;
    
    #----------------------------------------
    # DE: Macfilter anhalten
    # EN: stop macfilter
    #----------------------------------------
    stopfilter)
        /usr/local/bin/macfilter.sh "stopfilter"
        show_info "$_header_stopping" "$_text_stopping<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Auf Whitelist stellen
    # EN: set to whitelist
    #----------------------------------------
    whitelist)
        if [ `iptables -nvL macfilter | grep "Chain" | cut -dr -f2 | cut -b3-4` = "0" ]
        then
            check_rights "macfilter" "startfilter"
            /usr/local/bin/macfilter.sh "startfilter"
            show_info "$_header_starting" "$_text_starting"
            echo "<p/>"
        fi
        /usr/local/bin/macfilter.sh "whitelist"
        show_info "$_header_whitelist" "$_text_whitelist<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Auf Blacklist stellen
    # EN: set to blacklist
    #----------------------------------------
    blacklist)
        if [ `iptables -nvL macfilter | grep "Chain" | cut -dr -f2 | cut -b3-4` = "0" ]
        then
            check_rights "macfilter" "startfilter"
            /usr/local/bin/macfilter.sh "startfilter"
            show_info "$_header_starting" "$_text_starting"
            echo "<p/>"
        fi
        /usr/local/bin/macfilter.sh "blacklist"
        show_info "$_header_blacklist" "$_text_blacklist<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;

    #-------------------------------------------------------------------------------
    # DE: HTML ausgeben
    # EN: print HTML
    #-------------------------------------------------------------------------------
    view)
        if [ `iptables -nvL macfilter | grep "Chain" | cut -dr -f2 | cut -b3-4` = "0" ]
        then
            show_tab_header  "$_tab_blacklist"  "$myname?action=blacklist" \
                             "$_tab_whitelist"  "$myname?action=whitelist" \
                             "$_tab_stop"       no
        else
            if [ `iptables -nvL macfilter | grep "Whitelist" -c` = "0" ]
            then
                show_tab_header  "$_tab_blacklist"  no \
                                 "$_tab_whitelist"  "$myname?action=whitelist" \
                                 "$_tab_stop"       "$myname?action=stopfilter"
            else
                show_tab_header  "$_tab_blacklist"  "$myname?action=blacklist" \
                                 "$_tab_whitelist"  no \
                                 "$_tab_stop"       "$myname?action=stopfilter"
            fi
        fi
        
        ##-------------------------------------------------------------------------------
        ## DE: MAC Addressen Tabelle ausgeben
        ## EN: print MAC address table
        ##-------------------------------------------------------------------------------
        echo "<TABLE class=\"normtable\">
  <TR>
    <TH align=\"left\">$_table_header_mac</TH>
    <TH align=\"left\">$_table_header_action</TH>
  </TR>"

        macfilter_macs=`iptables -nvL macfilter | grep "MAC" | cut -dM -f2 | cut -b4-20`
        for macfilter_mac in $macfilter_macs
        do
            echo "  <FORM action=\"$myname\" method=\"get\"><TR>
    <INPUT type=\"hidden\" name=\"action\" value=\"remove\">
    <INPUT type=\"hidden\" name=\"mac\" value=\"$macfilter_mac\">
    <TD align=\"left\">$macfilter_mac</TD>
    <TD align=\"center\">
      <INPUT type=\"submit\" value=\"$_table_action_remove\" class=\"actions\">
    </TD>
  </TR></FORM>"
        done
          
        echo "  <FORM action=\"$myname\" method=\"get\"><TR>
    <INPUT type=\"hidden\" name=\"action\" value=\"add\">
    <TD align=\"left\">
      <INPUT type=\"text\" name=\"mac\" value=\"\">
    </TD>
    <TD align=\"center\"><INPUT type=\"submit\" value=\"$_table_action_add\" class=\"actions\"></TD>
  </TR></FORM>
</TABLE>"
        
        show_tab_footer
    ;;
    
    #----------------------------------------
    # DE: unbekannte Aktion
    # EN: unknown action
    #----------------------------------------
    *)
        echo "$_error_unknown_action"
    ;;
esac

#----------------------------------------
# DE: Ende des Dokuments ausgeben
# EN: print end of doc
#----------------------------------------
show_html_footer
##------------------------------------------------------------------------------
# macfilter.cgi -- EOF ---
##------------------------------------------------------------------------------