#!/bin/sh
##------------------------------------------------------------------------------
## local: opt\files\usr\local\bin\macfilter.sh
## fli4l: usr/local/bin/macfilter.sh
## DE: start, stop, hinzufgen und entfernen von MACs
## EN: start, stop, add/remove of MACs
##------------------------------------------------------------------------------
##
## Creation:       01.11.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Last modified:  01.12.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Version:        0.1.0-0.1.3
##
## Copyright (c) 2008 Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##------------------------------------------------------------------------------
## Parameter:   <$1 = "startfilter">        MACFilter starten
##              <$1 = "stopfilter">         MACFilter anhalten
##              <$1 = "blacklist">          MACs fr Blacklist benutzen
##              <$1 = "whitelist">          MACs fr Whitelist benutzen
##              <$1 = "add"> <$2 = MAC>     MAC hinzufgen
##              <$1 = "remove"> <$2 = MAC>  MAC entfernen
## Files:    /var/run/macfilter.conf
##------------------------------------------------------------------------------
. /etc/boot.d/base-helper
. /etc/rc.d/fwrules-helper
. /srv/www/include/cgi-helper
. /var/run/macfilter.conf

case $1 in
    #----------------------------------------
    # DE: MACFilter starten
    # EN: start MACFilter
    #----------------------------------------
    startfilter)
        #----------------------------------------
        # DE: MACFilter Chain einfgen
        # EN: include MACFilter chain 
        #----------------------------------------
        if [ `iptables -nvL macfilter | grep "Chain" | cut -dr -f2 | cut -b3-4` = "0" ]
        then
            [ $MACFILTER_DEBUG = "no" ] || echo "startfilter"
            for fwchain in $MACFILTER_CHAIN
            do
                [ $MACFILTER_DEBUG = "no" ] || echo "Chain: $fwchain"
                ins_rule filter "$fwchain" "any any macfilter" $MACFILTER_CHAINPOS "MACFilter"
            done
        fi
    ;;
    
    #----------------------------------------
    # DE: MACFilter anhalten
    # EN: stop MACFilter
    #----------------------------------------
    stopfilter)
        #----------------------------------------
        # DE: MACFilter Chain entfernen
        # EN: remove MACFilter chain 
        #----------------------------------------
        [ $MACFILTER_DEBUG = "no" ] || echo "stopfilter"
        for fwchain in $MACFILTER_CHAIN
        do
            [ $MACFILTER_DEBUG = "no" ] || echo "Chain: $fwchain"
            del_rule filter "$fwchain" "any any macfilter" "MACFilter"
        done
    ;;
    
    #----------------------------------------
    # DE: MACFilter als Blacklist benutzen
    # EN: use MACFilter as blacklist
    #----------------------------------------
    blacklist)
        [ $MACFILTER_DEBUG = "no" ] || echo "set to blacklist"
        
        macfilter_macs=`iptables -nvL macfilter | grep "MAC" | cut -dM -f2 | cut -b4-20`
        for macfilter_mac in $macfilter_macs
        do
            [ $MACFILTER_DEBUG = "no" ] || echo "MAC: $macfilter_mac"
            del_rule filter macfilter "mac:$macfilter_mac any RETURN" "MAC:$macfilter_mac"
            del_rule filter macfilter "mac:$macfilter_mac any DROP" "MAC:$macfilter_mac"
            add_rule filter macfilter "mac:$macfilter_mac any DROP" "MAC:$macfilter_mac"
        done
        
        if [ `iptables -nvL macfilter | grep "Whitelist" -c` != "0" ]
        then
            del_rule filter macfilter "any any DROP" "Whitelist"
        fi
    ;;
    
    #----------------------------------------
    # DE: MACFilter als Whitelist benutzen
    # EN: use MACFilter as whitelist
    #----------------------------------------
    whitelist)
        [ $MACFILTER_DEBUG = "no" ] || echo "set to whitelist"
        
        macfilter_macs=`iptables -nvL macfilter | grep "MAC" | cut -dM -f2 | cut -b4-20`
        for macfilter_mac in $macfilter_macs
        do
            [ $MACFILTER_DEBUG = "no" ] || echo "MAC: $macfilter_mac"
            del_rule filter macfilter "mac:$macfilter_mac any DROP" "MAC:$macfilter_mac"
            del_rule filter macfilter "mac:$macfilter_mac any RETURN" "MAC:$macfilter_mac"
            add_rule filter macfilter "mac:$macfilter_mac any RETURN" "MAC:$macfilter_mac"
        done
        
        add_rule filter macfilter "any any DROP" "Whitelist"
    ;;
    
    #----------------------------------------
    # DE: MAC der Liste hinzufgen
    # EN: add MAC to list
    #----------------------------------------
    add)
        macfilter_accesses=`iptables -nvL macfilter | grep "access" -c`
        macfilter_pos=`expr $macfilter_accesses + 1`
        
        if [ `iptables -nvL macfilter | grep "Whitelist" -c` = "0" ]
        then
            [ $MACFILTER_DEBUG = "no" ] || echo "add $2 to blacklist"
            ins_rule filter macfilter "mac:$2 any DROP" $macfilter_pos "MAC:$2"
        else
            [ $MACFILTER_DEBUG = "no" ] || echo "add $2 to whitelist"
            ins_rule filter macfilter "mac:$2 any RETURN" $macfilter_pos "MAC:$2"
        fi
    ;;
    
    #----------------------------------------
    # DE: MAC der Liste entfernen
    # EN: remove MAC to list
    #----------------------------------------
    remove)
        if [ `iptables -nvL macfilter | grep "Whitelist" -c` = "0" ]
        then
            [ $MACFILTER_DEBUG = "no" ] || echo "remove $2 from blacklist"
            del_rule filter macfilter "mac:$2 any DROP" "MAC:$2"
        else
            [ $MACFILTER_DEBUG = "no" ] || echo "remove $2 from whitelist"
            del_rule filter macfilter "mac:$2 any RETURN" "MAC:$2"
        fi
    ;;
esac
#----------------------------------------------------------------------------
# macfilter.sh -- EOF ---
#----------------------------------------------------------------------------